@@ -1,4 +1,5 @@
 import curses
+import copy
 import logging
 import time
 import _thread
@@ -13,6 +14,7 @@ from xmlabox.ximalaya import ximalaya
 from xmlabox.storage import Storage
 from xmlabox.base import Item, User
 from xmlabox.player import Player
+from xmlabox.browser import Brower
 
 LOG = logging.getLogger(__name__)
 '''
@@ -56,8 +58,11 @@ class Index():
     def __init__(self):
         LOG.info('start ximalayabox...')
         self._init_curses()
-        # 显示宽
-        self.weight = 60
+        # 显示参数
+        self._x = 10  #起点x
+        self._y = 5  #起点y
+        self.weight = 60  # 宽度
+
         self.islogin = False
         self.storage = Storage()
         self.user = User(None)
@@ -105,7 +110,11 @@ class Index():
         self.player.add_callback(vlc.EventType.MediaPlayerPositionChanged,
                                  self.update_time)
 
-    def _set_cookie(self):
+    def _set_cookie(self, cookie=None):
+        if cookie:
+            self.storage.cookie = cookie
+            self.storage.save()
+            return
         tmp_cookie_file = '/tmp/_xmla_cookie'
         if self.storage.cookie:
             return
@@ -205,8 +214,8 @@ class Index():
         self.screen.addstr(y, x, display_str, curses.color_pair(colorpair))
 
     def display_header(self):
-        x = 10
-        y = 5
+        x = self._x
+        y = self._y
         self.display_info('喜马拉雅', x, y, 1)
 
         if self.user:
@@ -235,28 +244,26 @@ class Index():
             self._display_help()
         if self.isexit:
             self._display_exit_window()
-        if not self.islogin:
-            self._display_login_window()
         self._display_pagination()
         self._display_player()
 
     def _display_comment(self):
-        x = 15
-        y = 10
+        x = self._x + 5
+        y = self._y + 5
         if self.current_items:
             self.display_info(
                 getattr(self.current_items[self.select_index], 'comment'), x,
                 y, 2)
 
     def _display_pagination(self):
-        x = 15
-        y = 23
+        x = self._x + 5
+        y = self._y + 18
         self.display_info('--- %s/%s ---' % (self.page_num, self.pages), x, y,
                           2)
 
     def _display_menu(self):
-        x = 15
-        y = 12
+        x = self._x + 5
+        y = copy.deepcopy(self._y + 7)
         # 每页个数
         num = 10
 
@@ -275,8 +282,8 @@ class Index():
 
     def _display_player(self):
         "进度条"
-        x = 12
-        y = 27
+        x = self._x + 2
+        y = self._y + 22
         progress_bar_len = 40
         play_progress_bar_len = 0
         if self.current_play:
@@ -303,29 +310,17 @@ class Index():
              sec2time(getattr(self.current_play, 'length', 0))), x, y + 1, 5)
 
     def _display_exit_window(self):
-        x = 25
-        y = 15
+        x = self._x + 15
+        y = self._y + 10
         self.display_info('-' * 26, x, y, 3)
         self.display_info('| 确认退出?              |', x, y + 1, 3)
         self.display_info('|%s|' % (' ' * 24), x, y + 2, 3)
         self.display_info('| 取消(ESC)  确认(ENTER) |', x, y + 3, 3)
         self.display_info('-' * 26, x, y + 4, 3)
 
-    def _display_login_window(self):
-        x = 12
-        y = 15
-        self.display_info('-' * 58, x, y, 5)
-        self.display_info(
-            '|                          请参考                        |', x,
-            y + 1, 5)
-        self.display_info(
-            '| https://github.com/ly798/xmlabox/blob/master/README.md |', x,
-            y + 2, 5)
-        self.display_info('-' * 58, x, y + 3, 5)
-
     def _display_help(self):
-        x = 30
-        y = 12
+        x = self._x + 20
+        y = self._y + 7
         self.display_info('-' * 27, x, y, 5)
         self.display_info('|%s?%s%s%s|' % (' ' * 9, ' ' * 5, '帮助', ' ' * 6), x,
                           y + 1, 5)
@@ -348,8 +343,8 @@ class Index():
         '''
         <key>   <log>
         '''
-        x = 10
-        y = 30
+        x = self._x
+        y = self._y + 25
         self.display_info('-' * self.weight, x, y)
         self.display_info('select: %s' % self.key, x, y + 1, 1)
         log_tmp_x = x + self.weight - wcswidth(self.log_string)
@@ -434,6 +429,7 @@ class Index():
                     if self.islogin:
                         self.save_history()
                     break
+
             # 退出
             elif key == ord('q'):
                 if not self.isexit:
@@ -449,7 +445,6 @@ class Index():
             # 上一页
             elif key == ord('p') or key == curses.KEY_PPAGE:
                 self._pre_page()
-
             # 下一页
             elif key == ord('n') or key == curses.KEY_NPAGE:
                 self._next_page()
@@ -466,13 +461,15 @@ class Index():
                             self._play()
                 else:
                     self.log_string = '无法播放'
+
             # 音量
             elif key == ord('+') or key == 43:
                 if self.storage.volume < 100:
-                    self.player.set_volume(self.storage.volume + 1)
+                    self.player.set_volume(self.storage.volume + 2)
             elif key == ord('-') or key == 95:
                 if self.storage.volume > 0:
-                    self.player.set_volume(self.storage.volume - 1)
+                    self.player.set_volume(self.storage.volume - 2)
+
             # 快进/快退
             elif key == 261:
                 self.player.set_time(self.current_play.time + 3)
@@ -484,16 +481,22 @@ class Index():
         curses.endwin()
 
     def user_logout(self):
-        # self.user = {}
-        # self.menu_stack.top = {'type': 0, 'items': LOGOUTED_ITEMS}
-        # self.select_index = 0
-        pass
+        self.islogin = False
+        self.user = User(None)
+        self._set_cookie(None)
+        self.menu_stack.top = {'type': 0, 'items': LOGOUTED_ITEMS}
+        self.select_index = 0
 
     def user_login(self):
-        # self.user = {'username': ''}
-        # self.menu_stack.top = {'type': 0, 'items': LOGINED_ITEMS}
-        # self.select_index = 0
-        pass
+        _thread.start_new_thread(self._login, ())
+
+    def _login(self):
+        cookie = Brower().get_cookie()
+        self._set_cookie(cookie)
+        self._valid_login()
+        if self.islogin:
+            self.menu_stack.top = {'type': 0, 'items': LOGINED_ITEMS}
+            self.select_index = 0
 
     def display_collect_list(self):
         """显示收藏列表"""
